==> haskell-tasty-kat-0.0.3-271-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-kat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-IlIb274FRfA81estv5AkIE
key:                  tasty-kat-0.0.3-IlIb274FRfA81estv5AkIE
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  21e7c93d99f89c853404a279b87d6fe9
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-kat-0.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-kat
hs-libraries:         HStasty-kat-0.0.3-IlIb274FRfA81estv5AkIE
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-kat-0.0.3-272-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-kat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-IlHpNmLtNRsAikKOXzzWOm
key:                  tasty-kat-0.0.3-IlHpNmLtNRsAikKOXzzWOm
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  9a58fc7354ad01acf47586499a1505fc
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-kat-0.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-kat
hs-libraries:         HStasty-kat-0.0.3-IlHpNmLtNRsAikKOXzzWOm
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    tasty-1.5.2-9G3Kf1f0lGYDWNQy5BbNrN

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
